import QtQuick
import QtQuick.Controls
import Generated.DesignSystem
import QtQuick.Timeline 1.0

Rectangle {
    id: trackView
    width: 234
    height: 253
    color: "transparent"
    property alias timelineAnimation: timelineAnimation
    property alias paceValueText: paceValue.text
    property alias paceText: pace.text
    property alias timeValueText: timeValue.text
    property alias minutesPerMileText: minutesPerMile.text
    property alias titleText: title.text

    Image {
        id: trackView_merged
        x: 46
        y: 116
        source: "assets/trackView_merged.png"
    }

    Rectangle {
        id: paceDisplay
        width: 113
        height: 70
        color: "transparent"
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.leftMargin: 61
        anchors.topMargin: 159
        Text {
            id: paceValue
            color: Colors.currentTheme.primary
            text: qsTr("0:00")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.leftMargin: 21
            anchors.rightMargin: 21
            anchors.bottomMargin: 30
            font.pixelSize: 32
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.NoWrap
            font.weight: Font.DemiBold
            font.family: "Exo"
        }

        Text {
            id: minutesPerMile
            color: Colors.currentTheme.primary
            text: qsTr("(MINS/Mi)")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.leftMargin: 48
            anchors.rightMargin: -1
            anchors.topMargin: 47
            anchors.bottomMargin: 4
            font.pixelSize: 14
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.NoWrap
            font.weight: Font.Medium
            font.family: "Exo"
        }

        Text {
            id: pace
            color: Colors.currentTheme.primary
            text: qsTr("PACE")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.rightMargin: 64
            anchors.topMargin: 43
            font.pixelSize: 20
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.NoWrap
            font.weight: Font.Medium
            font.family: "Exo"
        }
    }

    Rectangle {
        id: timeDisplay
        width: 204
        height: 113
        color: "transparent"
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.leftMargin: 15
        Text {
            id: timeValue
            color: Colors.currentTheme.primary
            text: qsTr("00:00")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.rightMargin: -1
            anchors.topMargin: 17
            font.pixelSize: 72
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignTop
            wrapMode: Text.NoWrap
            font.weight: Font.DemiBold
            font.family: "Exo"
        }

        Text {
            id: title
            color: Colors.currentTheme.primary
            text: qsTr("Time")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.leftMargin: 95
            anchors.rightMargin: 62
            anchors.bottomMargin: 85
            font.pixelSize: 20
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.NoWrap
            font.weight: Font.Medium
            font.family: "Exo"
        }

        Image {
            id: paceIconDark
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.leftMargin: 65
            anchors.topMargin: 4
            source: "assets/paceIconDark.png"
        }
    }

    Timeline {
        id: timeline
        animations: [
            TimelineAnimation {
                id: timelineAnimation
                running: false
                loops: -1
                duration: 10000
                to: 1000
                from: 0
            }
        ]
        startFrame: 0
        endFrame: 1000
        enabled: true

        KeyframeGroup {
            target: trackView_merged
            property: "x"
            Keyframe {
                value: 44
                frame: 0
            }

            Keyframe {
                value: 158
                frame: 200
            }

            Keyframe {
                value: 168
                frame: 220
            }

            Keyframe {
                value: 178
                frame: 240
            }

            Keyframe {
                value: 188
                frame: 260
            }

            Keyframe {
                value: 198
                frame: 280
            }

            Keyframe {
                value: 204
                frame: 300
            }

            Keyframe {
                value: 210
                frame: 320
            }

            Keyframe {
                value: 211
                frame: 340
            }

            Keyframe {
                value: 210
                frame: 380
            }

            Keyframe {
                value: 204
                frame: 400
            }

            Keyframe {
                value: 198
                frame: 420
            }

            Keyframe {
                value: 188
                frame: 440
            }

            Keyframe {
                value: 178
                frame: 460
            }

            Keyframe {
                value: 168
                frame: 480
            }

            Keyframe {
                value: 158
                frame: 500
            }

            Keyframe {
                value: 44
                frame: 700
            }

            Keyframe {
                value: 34
                frame: 720
            }

            Keyframe {
                value: 24
                frame: 740
            }

            Keyframe {
                value: 14
                frame: 760
            }

            Keyframe {
                value: 4
                frame: 780
            }

            Keyframe {
                value: -2
                frame: 800
            }

            Keyframe {
                value: -6
                frame: 820
            }

            Keyframe {
                value: -9
                frame: 840
            }

            Keyframe {
                value: -9
                frame: 860
            }

            Keyframe {
                value: -6
                frame: 880
            }

            Keyframe {
                value: -2
                frame: 900
            }

            Keyframe {
                value: 4
                frame: 920
            }

            Keyframe {
                value: 14
                frame: 940
            }

            Keyframe {
                value: 24
                frame: 960
            }

            Keyframe {
                value: 34
                frame: 980
            }

            Keyframe {
                value: 44
                frame: 1000
            }
        }

        KeyframeGroup {
            target: trackView_merged
            property: "y"
            Keyframe {
                value: 119
                frame: 0
            }

            Keyframe {
                value: 120
                frame: 220
            }

            Keyframe {
                value: 123
                frame: 240
            }

            Keyframe {
                value: 128
                frame: 260
            }

            Keyframe {
                value: 136
                frame: 280
            }

            Keyframe {
                value: 146
                frame: 300
            }

            Keyframe {
                value: 157
                frame: 320
            }

            Keyframe {
                value: 171
                frame: 340
            }

            Keyframe {
                value: 185
                frame: 360
            }

            Keyframe {
                value: 196
                frame: 380
            }

            Keyframe {
                value: 207
                frame: 400
            }

            Keyframe {
                value: 215
                frame: 420
            }

            Keyframe {
                value: 221
                frame: 440
            }

            Keyframe {
                value: 226
                frame: 460
            }

            Keyframe {
                value: 230
                frame: 480
            }

            Keyframe {
                value: 231
                frame: 500
            }

            Keyframe {
                value: 119
                frame: 200
            }

            Keyframe {
                value: 230
                frame: 720
            }

            Keyframe {
                value: 226
                frame: 740
            }

            Keyframe {
                value: 221
                frame: 760
            }

            Keyframe {
                value: 215
                frame: 780
            }

            Keyframe {
                value: 207
                frame: 800
            }

            Keyframe {
                value: 196
                frame: 820
            }

            Keyframe {
                value: 185
                frame: 840
            }

            Keyframe {
                value: 171
                frame: 860
            }

            Keyframe {
                value: 157
                frame: 880
            }

            Keyframe {
                value: 146
                frame: 900
            }

            Keyframe {
                value: 136
                frame: 920
            }

            Keyframe {
                value: 128
                frame: 940
            }

            Keyframe {
                value: 123
                frame: 960
            }

            Keyframe {
                value: 120
                frame: 980
            }

            Keyframe {
                value: 119
                frame: 1000
            }
        }
    }
}

/*##^##
Designer {
    D{i:0;uuid:"3b098de0-ec98-563c-abac-58cb6bf7179e"}D{i:6;uuid:"b1372238-7627-5fec-8b9c-4dc43bfee601"}
D{i:7;uuid:"e5de1b60-29e2-5867-804e-8674b41c24e5"}D{i:8;uuid:"59f1b576-9e94-534d-9429-7f16683fc266"}
}
##^##*/

